close all
clear all
clc

% Generating 21 random points
% tk = 20*rand(21,1) - 10;
tk = [-10:10]';
yk = erf(tk);

% Fitting data using polynomial least square
for deg = 1:5
    
    T{deg} = [];
    
    for i = 0:deg
        T{deg} = [T{deg} tk.^i];
    end;
    
    coeff{deg} = T{deg}\yk;
    
end;

t = [-10:10]';
y = erf(t);

% Getting output given the estimated coefficients
% and comparing it with actual output
figure;
for deg = 1:5
    
    T = [];
    
    for i = 0:deg
        T = [T t.^i];
    end;
    
    yest(:,deg) = T*coeff{deg};
    
    subplot(2,3,deg);
    plot(t,y,'k:');
    hold on; plot(t,yest(:,deg));
    title(['LS fitting using polynomial of degree ',num2str(deg)]);
    
end;

% Getting max error in the estimated and actual outputs
maxerr = max(repmat(y,[1,5]) - yest);

subplot(2,3,6);
plot(1:5,maxerr);
title('Error between estimated and actual output for different polynomial orders');
xlabel('Order (n)');
ylabel('Max. error');
ylim([0 1]);








clear('T','yest')

% Fitting data using polynomial least square
D = [1,3,5];
for deg = 1:length(D)
    
    T{deg} = [];
    
    for i = 0:D(deg)
        T{deg} = [T{deg} tk.^i];
    end;
    
    coeff{deg} = T{deg}\yk;
    
end;

t = [-10:10]';
y = erf(t);

% Getting output given the estimated coefficients
% and comparing it with actual output
figure;
for deg = 1:length(D)
    
    T = [];
    
    for i = 0:D(deg)
        T = [T t.^i];
    end;
    
    yest(:,deg) = T*coeff{deg};
    
    subplot(2,2,deg);
    plot(t,y,'k:');
    hold on; plot(t,yest(:,deg));
    title(['LS fitting using polynomial of degree ',num2str(D(deg))]);
    
end;

% Getting max error in the estimated and actual outputs
maxerr = max(repmat(y,[1,3]) - yest);

subplot(2,2,4);
plot(D,maxerr);
title('Error between estimated and actual output for different polynomial orders');
xlabel('Order (n)');
ylabel('Max. error');
ylim([0 1]);






clear('T','yest');

tk = [-10:10]';
yk = erf(tk);

% Fitting data using polynomial least square
T = ones(length(tk),1);
for i = 0:3
    T = [T exp(-tk.^2).*(1./(1.1+tk)).^i];
end;

coeffexp = T\yk;

t = [-10:10]';
y = erf(t);

% Getting output given the estimated coefficients
% and comparing it with actual output
T = ones(length(t),1);
for i = 0:3
    T = [T exp(-t.^2).*(1./(1.1+t)).^i];
end;
yestexp = T*coeffexp;

figure;plot(t,y,'k-');
hold on; plot(t,yestexp);
title('LS exponential fitting');
legend('Actual','LS approx.');